| Title: | What the Package Does (Title Case) |
|---|---|
| Description: | More about what it does (maybe more than one line) Use four spaces when indenting paragraphs within the Description. |
| Authors: | Leora Cramer [cre, aut] |
| Maintainer: | Leora Cramer <[email protected]> |
| License: | GPL-3 |
| Version: | 0.1.0 |
| Built: | 2026-05-22 19:51:37 UTC |
| Source: | https://github.com/LeoraCramer/ravecorrelation |
Function to load all development functions within an environment
dev_ravecorrelation(expose_functions = FALSE, reload = TRUE)dev_ravecorrelation(expose_functions = FALSE, reload = TRUE)
expose_functions |
logical indicating whether to expose all development functions to the global environment |
reload |
logical, do you want to fast-reload the package before load the functions? |